Package: fuseMLR
Type: Package
Title: Fusing Machine Learning in R
Version: 0.0.4
Authors@R: c(person(given = c("Cesaire", "J."),
                      family = c("K.", "Fouodo"),
                      role = c("aut", "cre"),
                      email = "cesaire.joris.kuete.fouodo@emory.edu"),
             person(given = c("Marina"),
                      family = c("Bleskina"),
                      role = c("ctb"),
                      email = "marina.bleskina@uni-luebeck.de")
            )
Maintainer: Cesaire J. K. Fouodo <cesaire.joris.kuete.fouodo@emory.edu>
Description: Recent technological advances have enable the simultaneous collection
    of multi-omics data i.e., different types or modalities of molecular data, 
    presenting challenges for integrative prediction modeling due to the heterogeneous,
    high-dimensional nature and possible missing modalities of some individuals. 
    We introduce this package for late integrative prediction modeling, enabling 
    modality-specific variable selection and prediction modeling, followed by the 
    aggregation of the modality-specific predictions to train a final meta-model. 
    This package facilitates conducting late integration predictive modeling in a 
    systematic, structured, and reproducible way.
License: GPL-3
Encoding: UTF-8
Imports: R6, stats, digest
Suggests: testthat (>= 3.0.0), UpSetR (>= 1.4.0), caret, ranger,
        glmnet, Boruta, knitr, rmarkdown, pROC, checkmate
Config/testthat/edition: 3
Depends: R (>= 3.6.0)
RoxygenNote: 7.3.3
Collate: 'Data.R' 'HashTable.R' 'Lrner.R' 'Model.R' 'PredictData.R'
        'PredictLayer.R' 'PredictMetaLayer.R' 'Predicting.R' 'Target.R'
        'TestData.R' 'TestLayer.R' 'TestMetaLayer.R' 'Testing.R'
        'TrainData.R' 'TrainLayer.R' 'TrainMetaLayer.R' 'Training.R'
        'VarSel.R' 'bestLayerLearner.R' 'cobra.R' 'createCobraPred.R'
        'createDif.R' 'createLoss.R' 'createWeights.R' 'multi_omics.R'
        'predict.bestLayerLearner.R' 'predict.cobra.R'
        'weightedMeanLearner.R' 'predict.weightedMeanLearner.R'
        'testingFunctions.R' 'trainingFunctions.R'
VignetteBuilder: knitr, rmarkdown
BugReports: https://github.com/imbs-hl/fuseMLR/issues
NeedsCompilation: no
Packaged: 2026-05-19 22:00:08 UTC; fouodo
Author: Cesaire J. K. Fouodo [aut, cre],
  Marina Bleskina [ctb]
Repository: CRAN
Date/Publication: 2026-05-20 06:40:02 UTC
Built: R 4.6.0; ; 2026-05-20 08:16:23 UTC; unix
