# Generated by roxygen2: do not edit by hand

S3method(predict,Training)
S3method(predict,bestLayerLearner)
S3method(predict,cobra)
S3method(predict,weightedMeanLearner)
S3method(summary,Testing)
S3method(summary,Training)
export(Data)
export(HashTable)
export(Lrner)
export(Model)
export(PredictData)
export(PredictLayer)
export(PredictMetaLayer)
export(Predicting)
export(Target)
export(TestData)
export(TestLayer)
export(TestMetaLayer)
export(Testing)
export(TrainData)
export(TrainLayer)
export(TrainMetaLayer)
export(Training)
export(VarSel)
export(bestLayerLearner)
export(cobra)
export(createTestLayer)
export(createTesting)
export(createTrainLayer)
export(createTrainMetaLayer)
export(createTraining)
export(extractData)
export(extractModel)
export(fusemlr)
export(upsetplot)
export(varSelection)
export(weightedMeanLearner)
importFrom(R6,R6Class)
importFrom(digest,digest)
importFrom(stats,complete.cases)
importFrom(stats,weighted.mean)
