% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/testingFunctions.R
\name{createTestLayer}
\alias{createTestLayer}
\title{createTestLayer}
\usage{
createTestLayer(testing, test_layer_id, test_data)
}
\arguments{
\item{testing}{\code{Testing} \cr
Testing object where the created layer will be stored.}

\item{test_layer_id}{\code{character} \cr
ID of the testing layer to be created.}

\item{test_data}{\code{data.frame} \cr
Data modality to be stored in \link{TestData}.}
}
\value{
The updated \link{Testing} object (with the new layer) is returned.
}
\description{
Creates and stores a \link{TestLayer} on the \link{Testing} object passed as argument.
}
